@@ -59,16 +59,20 @@ class ChangeHandler(FileSystemEventHandler):
 
         what = "directory" if event.is_directory else "file"
         print("Created", what, event.src_path)
-        if event.is_directory:
+        path = Path(event.src_path)
+        query = path.name
+        if event.is_directory and not query.startswith("_"):
             from .hypertag import HyperTag
 
             ht = HyperTag()
             print("Populating with query results...")
-            path = Path(event.src_path)
-            query = path.name
             args = re.findall(r"'.*?'|\".*?\"|\S+", query)
             args = [e.replace('"', "").replace("'", "") for e in args]
-            top_k = [int(a.split("=")[-1]) for a in args if a.startswith("top_k=")][0]
+            top_k = [int(a.split("=")[-1]) for a in args if a.startswith("top_k=")]
+            if top_k:
+                top_k = top_k[0]
+            else:
+                top_k = 10
             args = [a for a in args if not a.startswith("top_k=")]
 
             parent_tag_name = path.parent.name
