@@ -1,6 +1,6 @@
 import os
 import rpyc  # type: ignore
-from shutil import rmtree
+from shutil import rmtree, move
 import sqlite3
 import json
 from multiprocessing import Pool
@@ -183,19 +183,21 @@ class HyperTag:
 
         for tag_id, name in tag_ids_names:
             file_paths_names = self.db.get_file_paths_names_by_tag_id(tag_id)
-            root_tag_path = root_path / name
-            symlink_path = root_tag_path
-            if tag_id not in leaf_tag_ids:
-                os.makedirs(root_tag_path / "_files", exist_ok=True)
-                symlink_path = root_tag_path / "_files"
-            elif len(file_paths_names) > 0:
-                os.makedirs(root_tag_path, exist_ok=True)
-            for file_path, file_name in file_paths_names:
-                try:
-                    os.symlink(Path(file_path), symlink_path / file_name)
-                except FileExistsError:
-                    pass
-            self.mount(root_tag_path, tag_id)
+            if len(file_paths_names) > 0:
+                underscore_root_tag_path = root_path / ("_" + name)
+                os.makedirs(underscore_root_tag_path, exist_ok=True)
+                root_tag_path = root_path / (name)
+                move(underscore_root_tag_path, root_tag_path)  # Needed for daemon
+                symlink_path = root_tag_path
+                if tag_id not in leaf_tag_ids:
+                    symlink_path = root_tag_path / "_files"
+                    os.makedirs(symlink_path, exist_ok=True)
+                for file_path, file_name in file_paths_names:
+                    try:
+                        os.symlink(Path(file_path), symlink_path / file_name)
+                    except FileExistsError:
+                        pass
+                self.mount(root_tag_path, tag_id)
 
     def import_tags(self, import_path: str):
         """Import files with tags inferred from existing directory hierarchy
@@ -436,20 +438,25 @@ def main():
         "add": ht.add,
         "import": ht.import_tags,
         "tag": ht.tag,
+        "t": ht.tag,
         "untag": ht.untag,
         "metatag": ht.metatag,
+        "tt": ht.metatag,
         "merge": ht.merge,
         "show": ht.show,
         "tags": ht.tags,
         "metatags": ht.metatags,
         "query": ht.query,
+        "q": ht.query,
         "set_hypertagfs_dir": ht.set_hypertagfs_dir,
         "mount": ht.mount,
         "daemon": daemon,
         "graph": graph,
         "index": ht.index,
         "search_image": ht.search_image,
+        "si": ht.search_image,
         "search": ht.search,
+        "s": ht.search,
     }
     fire.Fire(fire_cli)
 
