@@ -287,7 +287,9 @@ class Persistor:
         return data
 
     def get_unindexed_file_paths(self) -> List[str]:
-        self.c.execute("SELECT path FROM files WHERE embedding_vector is NULL")
+        self.c.execute(
+            "SELECT path FROM files WHERE embedding_vector is NULL AND clean_text is NULL"
+        )
         data = [str(e[0]) for e in self.c.fetchall()]
         return data
 
@@ -315,8 +317,11 @@ class Persistor:
         )
 
     def remove_tag_from_file(self, tag_name: str, file_name: str):
-        file_id = self.get_file_id_by_name(file_name)
-        tag_id = self.get_tag_id_by_name(tag_name)
+        try:
+            file_id = self.get_file_id_by_name(file_name)
+            tag_id = self.get_tag_id_by_name(tag_name)
+        except TypeError:
+            return
         self.c.execute("DELETE FROM tags_files WHERE file_id = ? AND tag_id = ?", [file_id, tag_id])
         self.conn.commit()
 
@@ -350,7 +355,7 @@ class Persistor:
         )
         self.conn.commit()
 
-    def get_add_clean_text_of_file(self, file_path: str):
+    def get_clean_text_of_file(self, file_path: str):
         self.c.execute(
             """
             SELECT clean_text FROM files WHERE path LIKE ?
